@@ -1,20 +1,23 @@
 import datetime
-import chardet
 import inspect
 import logging
 import sys
-import time
 import getpass
-import dbm
-import dbm.gnu
 import psutil
-from os.path import exists
+from importlib import util as importlib_util
+import time
 import re
 from pathlib import Path
-from importlib import util as importlib_util
+import timeit
 
 global logger
 global logging_is_on_flag
+
+global logger_datetime
+global logger_iso_format_datetime
+global logger_database_format_datetime
+global my_logger_program_name_for_database_routine
+
 global logger_to_file
 global logging_level
 global qetl_code_dir        # Parent of qualys_etl directory
@@ -25,58 +28,58 @@ import qualys_etl
 logging_is_on_flag = False
 
 
-def get_dbm_type(file_name):
-    dbm_type = dbm.whichdb(file_name)
-    if dbm_type == '':
-        dbm_type = 'unknown'
-
-    return dbm_type
+# def get_dbm_type(file_name):
+#     dbm_type = dbm.whichdb(file_name)
+#     if dbm_type == '':
+#         dbm_type = 'unknown'
+#
+#     return dbm_type
 
 
-def flatten_nest(nested_data):  # Flatten nested dictionary into string
-    def nested_items():
-        if isinstance(nested_data, list):
-            for key, value in enumerate(nested_data):
-                if isinstance(value, dict) or isinstance(value, list):
-                    for nested_key, nested_value in flatten_nest(value).items():
-                        yield str(key) + "." + nested_key, nested_value
-                else:
-                    yield str(key), value
-        else:
-            for key, value in nested_data.items():
-                if isinstance(value, dict) or isinstance(value, list):
-                    for nested_key, nested_value in flatten_nest(value).items():
-                        yield key + "." + nested_key, nested_value
-                else:
-                    yield key, value
-    return dict(nested_items())
-
-
-def remove_low_high_values(chunk):  # Remove utf-8 values other than utf-8 decimal 10, 32-126
-    encoding = chardet.detect(chunk)['encoding']
-    chunk = chunk.decode(encoding, 'replace')
-    new_chunk = ''
-    for index in range(0, len(chunk)):
-        try:
-            size = ord(chunk[index])
-            if (size == 10) or (size == 9) or (127 > size > 31):
-                new_chunk = new_chunk + chunk[index]
-            else:
-                new_chunk = new_chunk + ""
-        except Exception as e:
-            new_chunk = new_chunk + ""
-    chunk = new_chunk.encode('utf-8')
-    return chunk
-
-
-def truncate_csv_cell(max_length=32700, csv_cell="", truncated_field_list="", csv_column=""):
-    if max_length == 0:
-        pass
-    elif len(csv_cell) > max_length:
-        truncated_field_list = f"{truncated_field_list}{csv_column}:{len(csv_cell):,} truncated_at: {max_length:,}\n"
-        csv_cell = csv_cell[:max_length]
-
-    return csv_cell, truncated_field_list
+# def flatten_nest(nested_data):  # Flatten nested dictionary into string
+#     def nested_items():
+#         if isinstance(nested_data, list):
+#             for key, value in enumerate(nested_data):
+#                 if isinstance(value, dict) or isinstance(value, list):
+#                     for nested_key, nested_value in flatten_nest(value).items():
+#                         yield str(key) + "." + nested_key, nested_value
+#                 else:
+#                     yield str(key), value
+#         else:
+#             for key, value in nested_data.items():
+#                 if isinstance(value, dict) or isinstance(value, list):
+#                     for nested_key, nested_value in flatten_nest(value).items():
+#                         yield key + "." + nested_key, nested_value
+#                 else:
+#                     yield key, value
+#     return dict(nested_items())
+#
+#
+# def remove_low_high_values(chunk):  # Remove utf-8 values other than utf-8 decimal 10, 32-126
+#     encoding = chardet.detect(chunk)['encoding']
+#     chunk = chunk.decode(encoding, 'replace')
+#     new_chunk = ''
+#     for index in range(0, len(chunk)):
+#         try:
+#             size = ord(chunk[index])
+#             if (size == 10) or (size == 9) or (127 > size > 31):
+#                 new_chunk = new_chunk + chunk[index]
+#             else:
+#                 new_chunk = new_chunk + ""
+#         except Exception as e:
+#             new_chunk = new_chunk + ""
+#     chunk = new_chunk.encode('utf-8')
+#     return chunk
+#
+#
+# def truncate_csv_cell(max_length=32700, csv_cell="", truncated_field_list="", csv_column=""):
+#     if max_length == 0:
+#         pass
+#     elif len(csv_cell) > max_length:
+#         truncated_field_list = f"{truncated_field_list}{csv_column}:{len(csv_cell):,} truncated_at: {max_length:,}\n"
+#         csv_cell = csv_cell[:max_length]
+#
+#     return csv_cell, truncated_field_list
 
 
 def check_python_version():
@@ -104,13 +107,13 @@ def get_file_mtime(path_to_file):
         return statinfo.st_mtime
 
 
-def dbm_type_message(dbm_file):
-    dbm_type = get_dbm_type(str(dbm_file))
-    if dbm_type == "dbm.gnu":
-        message = "dbm.gnu is best performing DBM, you are good to go!"
-    else:
-        message = f"{dbm_type} may result in errors.  Please consider moving to dbm.gnu which is optimal."
-    return message
+# def dbm_type_message(dbm_file):
+#     dbm_type = get_dbm_type(str(dbm_file))
+#     if dbm_type == "dbm.gnu":
+#         message = "dbm.gnu is best performing DBM, you are good to go!"
+#     else:
+#         message = f"{dbm_type} may result in errors.  Please consider moving to dbm.gnu which is optimal."
+#     return message
 
 
 def get_sqlite_version():
@@ -129,11 +132,19 @@ def get_sqlite_version():
 def setup_logging_stdout(log_level=logging.INFO, my_logger_prog_name=None):
     global logger
     global logging_is_on_flag
+    global logger_datetime
+    global logger_iso_format_datetime
+    global logger_database_format_datetime
+    global my_logger_program_name_for_database_routine
 
     logging_is_on_flag = True
     logging.Formatter.converter = time.gmtime
     d = datetime.datetime.utcnow()
     td = f"{d.year}{d.month:02d}{d.day:02d}{d.hour:02d}{d.minute:02d}{d.second:02d}"
+    logger_datetime = td
+    logger_iso_format_datetime = f"{d.year}-{d.month:02d}-{d.day:02d}T{d.hour:02d}:{d.minute:02d}:{d.second:02d}Z"
+    logger_database_format_datetime = f"{d.year}-{d.month:02d}-{d.day:02d} {d.hour:02d}:{d.minute:02d}:{d.second:02d}"
+    my_logger_program_name_for_database_routine = my_logger_prog_name
     username = getpass.getuser()
     prog = Path(__file__).name
     if my_logger_prog_name is not None:
@@ -142,8 +153,7 @@ def setup_logging_stdout(log_level=logging.INFO, my_logger_prog_name=None):
     prog = f"{prog}: {td}"
 
     logging.basicConfig(format=f"%(asctime)s | %(levelname)-8s | {prog:54s} | {username:15} | %(funcName)-60s | %(message)s",
-                        level=log_level,
-                        )
+                        level=log_level,)
 
     logger = logging.getLogger()  # Useful in qetl_manage_user when we want to set the name.
     logger.info(f"PROGRAM:     {sys.argv}")
@@ -151,14 +161,14 @@ def setup_logging_stdout(log_level=logging.INFO, my_logger_prog_name=None):
     logger.info(f"LOGGING SUCCESSFULLY SETUP FOR STREAMING")
 
 
-def setup_logging_to_file(logfile_path, log_level=logging.INFO):
-    logging.Formatter.converter = time.gmtime
-    logging.basicConfig(format=f"%(asctime)s - %(levelname)s - %(message)s",
-                        filename=logfile_path,
-                        level=log_level)
-    global logger
-    logger = logging.getLogger(__name__)
-    logger.info(f"LOGGING SUCCESSFULLY SETUP TO {str(logfile_path)}")
+# def setup_logging_to_file(logfile_path, log_level=logging.INFO):
+#     logging.Formatter.converter = time.gmtime
+#     logging.basicConfig(format=f"%(asctime)s - %(levelname)s - %(message)s",
+#                         filename=logfile_path,
+#                         level=log_level)
+#     global logger
+#     logger = logging.getLogger(__name__)
+#     logger.info(f"LOGGING SUCCESSFULLY SETUP TO {str(logfile_path)}")
 
 
 def lineno():
@@ -181,9 +191,9 @@ def check_modules():
         exit(1)
 
 
-def set_logging_level(log_level=logging.INFO):
-    global logging_level
-    logging_level = log_level  # Set to logging.WARNING to only log Warnings and Errors.
+# def set_logging_level(log_level=logging.INFO):
+#     global logging_level
+#     logging_level = log_level  # Set to logging.WARNING to only log Warnings and Errors.
 
 
 def set_qetl_code_dir(log=True): # Module Directories
@@ -228,24 +238,24 @@ def set_qetl_code_dir(log=True): # Module Directories
     logger.info(f"etld_host_list        - {qetl_code_dir_child_api_host_list}")
 
 
-def log_dbm_info(file_name, msg=""):
-    if exists(str(file_name)):
-        dbm_type = get_dbm_type(str(file_name))
-        logger.info(f"{msg}dbm type - {dbm_type} - {str(file_name)}")
-        if dbm_type == "dbm.gnu" or dbm_type is None:
-            pass
-        else:
-            logger.info(f"{msg}dbm type warning - {dbm_type} may lead to inconsistent results.")
-            logger.info(f"{msg}dbm type warning - {dbm_type} move to linux gnu dbm.")
+# def log_dbm_info(file_name, msg=""):
+#     if exists(str(file_name)):
+#         dbm_type = get_dbm_type(str(file_name))
+#         logger.info(f"{msg}dbm etl_workflow_validation_type - {dbm_type} - {str(file_name)}")
+#         if dbm_type == "dbm.gnu" or dbm_type is None:
+#             pass
+#         else:
+#             logger.info(f"{msg}dbm etl_workflow_validation_type warning - {dbm_type} may lead to inconsistent results.")
+#             logger.info(f"{msg}dbm etl_workflow_validation_type warning - {dbm_type} move to linux gnu dbm.")
 
 
-def log_dbm_count_of_keys_found(file_name):
-    if exists(str(file_name)):
-        dbm_type = get_dbm_type(str(file_name))
-        if dbm_type == "dbm.gnu" or dbm_type is None:
-            with dbm.gnu.open(str(file_name), 'rf') as sd:
-                count = len(sd)
-                logger.info(f"keys found: {count:,} in dbm.gnu shelve: {str(file_name)}")
+# def log_dbm_count_of_keys_found(file_name):
+#     if exists(str(file_name)):
+#         dbm_type = get_dbm_type(str(file_name))
+#         if dbm_type == "dbm.gnu" or dbm_type is None:
+#             with dbm.gnu.open(str(file_name), 'rf') as sd:
+#                 count = len(sd)
+#                 logger.info(f"keys found: {count:,} in dbm.gnu shelve: {str(file_name)}")
 
 
 def get_formatted_file_info_dict(file_name):
@@ -289,25 +299,55 @@ def log_file_info(file_name, msg1='output file'):
                 f"change time: {file_info.get('file_change_time')}")
 
 
-def file_is_locked(test_lock_file=None):
-    # TODO determine if checking locking in each method is needed.
-    # TODO note that all actions should be run through qetl_manage_user which locks the jobstream.
-    try:
-        if Path(test_lock_file).is_file():
-            with open(test_lock_file, 'wb+') as tlf:        # If locked, exit.
-                # lock file is free
-                return False
-        else:
-            # lock file doesn't exist
-            return False
-    except Exception as e:
-        return True
+# def file_is_locked(test_lock_file=None):
+#     # TODO determine if checking locking in each method is needed.
+#     # TODO note that all actions should be run through qetl_manage_user which locks the jobstream.
+#     try:
+#         if Path(test_lock_file).is_file():
+#             with open(test_lock_file, 'wb+') as tlf:        # If locked, exit.
+#                 # lock file is free
+#                 return False
+#         else:
+#             # lock file doesn't exist
+#             return False
+#     except Exception as e:
+#         return True
+
+class TimerObj:
+    def __init__(self):
+        self.start_time = timeit.default_timer()
+        self.current_time = self.start_time
+        self.time_elapsed = 0
+
+    def reset_timer(self):
+        self.start_time = timeit.default_timer()
+        self.current_time = self.start_time
+        self.time_elapsed = 0
+
+    def get_time_elapsed(self) -> float:
+        current_time = timeit.default_timer()
+        time_elapsed = (current_time - self.start_time)
+        return time_elapsed
+
+    def if_time_elapsed_past_max_time(self, max_time=300) -> bool:
+        time_elapsed = self.get_time_elapsed()
+        time_elapsed_flag = False
+        if time_elapsed > max_time:
+            time_elapsed_flag = True
+        return time_elapsed_flag
 
 
 class DisplayCounterToLog:
+    # TODO Create method to display counters as json.
+    # {"Q_Host_List": "283,129", "Q_Host_List_Detection_HOSTS": "171,452","Q_Host_List_Detection_QIDS": "1,335,871"}
     def __init__(self, display_counter_at=10000, logger_func=None, display_counter_log_message="count"):
         self.counter = 0
         self.display_counter = 0
+        self.batch_name = ''
+        self.batch_number = 0
+        self.batch_date = ''
+        self.status_table_name = 'TABLE_NAME'
+        self.status_name_column = 'TABLE_NAME_LOAD_STATUS'
         self.display_counter_at = display_counter_at
         self.logger_func = logger_func
         self.display_counter_log_message = display_counter_log_message
@@ -319,6 +359,43 @@ class DisplayCounterToLog:
     def get_counter(self):
         return self.counter
 
+    def get_batch_name(self):
+        return self.batch_name
+
+    def set_batch_name(self, batch_name):
+        self.batch_name = batch_name
+
+    def get_batch_number(self):
+        return self.batch_number
+
+    def get_batch_date(self):
+        return self.batch_date
+
+    def set_batch_date(self, batch_date):
+        self.batch_date = batch_date
+
+    def get_status_table_name(self):
+        return self.status_table_name
+
+    def get_status_name_column(self):
+        return self.status_name_column
+
+    def update_batch_info(self, batch_name, batch_number, batch_date, status_table_name, status_name_column):
+        self.batch_name = batch_name
+        self.batch_number = batch_number
+        self.batch_date = batch_date
+        self.status_table_name = status_table_name
+        self.status_name_column = status_name_column
+
+    def get_batch_info(self):
+        return {
+            'batch_name': self.batch_name,
+            'batch_number': self.batch_number,
+            'batch_date': self.batch_date,
+            'etl_workflow_status_table_name': self.status_table_name,
+            'status_name_column': self.status_name_column
+        }
+
     def display_counter_to_log(self):
         self.update_counter()
         if self.display_counter >= self.display_counter_at:
@@ -441,13 +518,13 @@ def if_ram_space_size_is_low_log_warning(logger_method=print):
                       f'Consider increasing RAM to support larger batch jobs and sql queries')
 
 
-def proc_table(logger_method=print):
-    for proc in psutil.process_iter(['pid', 'name']):
-        if 'python' in proc.info['name']:
-            p = psutil.Process(proc.pid)
-            #p.open_files().count()
-            logger_method(f'SYS STAT: PID COMMAND={proc.pid}, OPEN_FILES={p.open_files()}, CMD={p.cmdline()}')
-            logger_method(f'PID STAT: PID CHILDREN={proc.pid}, CHILDREN={p.children(recursive=True)}')
+# def proc_table(logger_method=print):
+#     for proc in psutil.process_iter(['pid', 'name']):
+#         if 'python' in proc.info['name']:
+#             p = psutil.Process(proc.pid)
+#             #p.open_files().count()
+#             logger_method(f'SYS STAT: PID COMMAND={proc.pid}, OPEN_FILES={p.open_files()}, CMD={p.cmdline()}')
+#             logger_method(f'PID STAT: PID CHILDREN={proc.pid}, CHILDREN={p.children(recursive=True)}')
 
 
 def get_disk_usage_pct(data_dir="/opt/qetl/users"):
