@@ -469,20 +469,35 @@ def help_message(notes):
                                Example:
                                {{"q_username": "your userid", "q_password": "your password", "q_api_fqdn_server": "api fqdn", "q_gateway_fqdn_server": "gateway api fqdn"}}
       
-      etld_config_settings.yaml notes:
-         1. To Enable CSV Distribution, add the following keys to etld_config_settings.yaml and toggle on/off them via True or False
-              kb_distribution_csv_flag: True                    # populates qetl_home/data/knowledgebase_distribution_dir
-              host_list_distribution_csv_flag: True             # populates qetl_home/data/host_list_distribution_dir
-              host_list_detection_distribution_csv_flag: True   # populates qetl_home/data/host_list_detection_distribution_dir
-              asset_inventory_distribution_csv_flag: True       # populates qetl_home/data/asset_inventory_distribution_dir
-              was_distribution_csv_flag: True                   # populates qetl_home/data/was_distribution_dir
+    Example: 
+    
+    qetl_manage_user -u [path] -e etl_host_list_detection -d 1970-01-01T00:00:00Z
+
+     Inputs: 
+       - KnowledgeBase API, Host List API, Host List Detection API.
+     Outputs:
+       - XML, JSON, SQLITE, AND Distribution_Directory of CSV BATCH FILES PREPARED FOR DATABASE INGESTION.
+       - ETL KnowledgeBase
+         - /api/2.0/fo/knowledge_base/vuln/?action=list
+       - ETL Host List
+         - /api/2.0/fo/asset/host/?action=list
+       - ETL Host List Detection - Stream of batches immediately ready for downstream database ingestion.
+         - /api/2.0/fo/asset/host/vm/detection/?action=list
+         
+   etld_config_settings.yaml notes:
+       1. To Enable CSV Distribution, add the following keys to etld_config_settings.yaml and toggle on/off them via True or False
+            kb_distribution_csv_flag: True                    # populates qetl_home/data/knowledgebase_distribution_dir
+            host_list_distribution_csv_flag: True             # populates qetl_home/data/host_list_distribution_dir
+            host_list_detection_distribution_csv_flag: True   # populates qetl_home/data/host_list_detection_distribution_dir
+            asset_inventory_distribution_csv_flag: True       # populates qetl_home/data/asset_inventory_distribution_dir
+            was_distribution_csv_flag: True                   # populates qetl_home/data/was_distribution_dir
               
-              These files are prepared for database load, tested with mysql.  No headers are present.  
-              Contact your Qualys TAM and schedule a call with David Gregory if you need assistance with this option.
+            These files are prepared for database load, tested with mysql.  No headers are present.  
+            Contact your Qualys TAM and schedule a call with David Gregory if you need assistance with this option.
             
-         2. To enable TruRisk, ask your TAM to add TruRisk to your subscription, then update the following keys in your etld_config_settings.yaml
-            host_list_payload_option: {{'show_ars': '1', 'show_ars_factors': '1'}}
-            host_list_detection_payload_option: {{'show_qds': '1', 'show_qds_factors': '1'}}
+       2. To enable TruRisk, ask your TAM to add TruRisk to your subscription, then update the following keys in your etld_config_settings.yaml
+          host_list_payload_option: {{'show_ars': '1', 'show_ars_factors': '1'}}
+          host_list_detection_payload_option: {{'show_qds': '1', 'show_qds_factors': '1'}}
                                
       QualysETL Version: {qualys_etl.__version__}
     '''
